Module error

Module error 

Structs

Error
An error type for serial port operations.

Enums

ErrorKind
Categories of errors that can occur when interacting with serial ports.

Type Aliases

Result
A type for results generated by interacting with serial ports.